package com.dcsoft.system.face.service;

import com.dcsoft.system.face.domain.FaceClasses;

import java.util.List;

/**
 * 班级信息Service接口
 *
 * @author dcsoft
 * @date 2023-05-22
 */
public interface IFaceClassesService
{
    /**
     * 查询班级信息
     *
     * @param id 班级信息主键
     * @return 班级信息
     */
    public FaceClasses selectFaceClassesById(Long id);

    /**
     * 查询班级信息列表
     *
     * @param faceClasses 班级信息
     * @return 班级信息集合
     */
    public List<FaceClasses> selectFaceClassesList(FaceClasses faceClasses);

    /**
     * 新增班级信息
     *
     * @param faceClasses 班级信息
     * @return 结果
     */
    public int insertFaceClasses(FaceClasses faceClasses);

    /**
     * 修改班级信息
     *
     * @param faceClasses 班级信息
     * @return 结果
     */
    public int updateFaceClasses(FaceClasses faceClasses);

    /**
     * 批量删除班级信息
     *
     * @param ids 需要删除的班级信息主键集合
     * @return 结果
     */
    public int deleteFaceClassesByIds(Long[] ids);

    /**
     * 删除班级信息信息
     *
     * @param id 班级信息主键
     * @return 结果
     */
    public int deleteFaceClassesById(Long id);
}
